Fix typos
diff --git a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalDiffIntegrationTest.java b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalDiffIntegrationTest.java
index 722749a..17f065a 100644
--- a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalDiffIntegrationTest.java
+++ b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalDiffIntegrationTest.java
@@ -30,8 +30,8 @@
  * Should only be called from the tycho build since it used the emfcompare-git-pgm update to create the
  * provided platform.
  * <p>
- * If you need to run it locally please set the system variable "emfcompare-git-pgm--updasite" to the location
- * of update holding emfcompare-git-pgm plugins.
+ * If you need to run it locally please set the system variable "emfcompare-git-pgm--updatesite" to the
+ * location of update holding emfcompare-git-pgm plugins.
  * </p>
  * 
  * @author <a href="mailto:arthur.daussy@obeo.fr">Arthur Daussy</a>
diff --git a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeCommandIntegrationTest.java b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeCommandIntegrationTest.java
index c6864da..3c5fc00 100644
--- a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeCommandIntegrationTest.java
+++ b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeCommandIntegrationTest.java
@@ -35,8 +35,8 @@
  * Should only be called from the tycho build since it used the emfcompare-git-pgm update to create the
  * provided platform.
  * <p>
- * If you need to run it locally please set the system variable "emfcompare-git-pgm--updasite" to the location
- * of update holding emfcompare-git-pgm plugins.
+ * If you need to run it locally please set the system variable "emfcompare-git-pgm--updatesite" to the
+ * location of update holding emfcompare-git-pgm plugins.
  * </p>
  * 
  * @author <a href="mailto:arthur.daussy@obeo.fr">Arthur Daussy</a>
diff --git a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeToolIntegrationTest.java b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeToolIntegrationTest.java
index e51a2d4..888d97a 100644
--- a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeToolIntegrationTest.java
+++ b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/internal/cmd/LogicalMergeToolIntegrationTest.java
@@ -31,8 +31,8 @@
  * Should only be called from the tycho build since it used the emfcompare-git-pgm update to create the
  * provided platform.
  * <p>
- * If you need to run it locally please set the system variable "emfcompare-git-pgm--updasite" to the location
- * of update holding emfcompare-git-pgm plugins.
+ * If you need to run it locally please set the system variable "emfcompare-git-pgm--updatesite" to the
+ * location of update holding emfcompare-git-pgm plugins.
  * </p>
  * 
  * @author <a href="mailto:arthur.daussy@obeo.fr">Arthur Daussy</a>
diff --git a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/suite/AllIntegrationTests.java b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/suite/AllIntegrationTests.java
index 0ca2bf8..5380800 100644
--- a/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/suite/AllIntegrationTests.java
+++ b/plugins/org.eclipse.emf.compare.git.pgm.tests/src/org/eclipse/emf/compare/git/pgm/suite/AllIntegrationTests.java
@@ -33,8 +33,8 @@
  * Should only be called from the tycho build since it used the emfcompare-git-pgm update to create the
  * provided platform.
  * <p>
  * If you need to run it locally please set the system variable "emfcompare-git-pgm--updasite" to the location
  * of update holding emfcompare-git-pgm plugins.
  * </p>
  * 
  * @author <a href="mailto:arthur.daussy@obeo.fr">Arthur Daussy</a>
@@ -47,7 +47,7 @@
 	/**
 	 * System property to set to the emfcompare-git-pgm update site location.
 	 */
-	private static final String EMFCOMPARE_GIT_PGM_UPDASITE_SYS_PROP = "emfcompare-git-pgm--updasite"; //$NON-NLS-1$
+	private static final String EMFCOMPARE_GIT_PGM_UPDASITE_SYS_PROP = "emfcompare-git-pgm--updatesite"; //$NON-NLS-1$
 
 	private static final String TMP_DIRECTORY_PREFIX = "emfcompare-git-pgm"; //$NON-NLS-1$
@@ -33,8 +33,8 @@
  * provided platform.
  * <p>
- * If you need to run it locally please set the system variable "emfcompare-git-pgm--updasite" to the location
- * of update holding emfcompare-git-pgm plugins.
+ * If you need to run it locally please set the system variable "emfcompare-git-pgm--updatesite" to the
+ * location of update holding emfcompare-git-pgm plugins.
  * </p>
  * 